    	sci note:

    		course:
    			1. keep numbers as fractions.
    			2. store numbers as fraction strings.

    			3. for the sake of readability,
    			   print numbers is sci note.

    		import numpy
    			def calc (
    				number
    			):
    				return numpy.format_float_scientific (
    					number,
    					unique = False,
    					precision = 15,
    					exp_digits = 2
    				)

    		python3 values aren't store in scientific notation.

    			#
    			#	prints the number in sci note
    			#
    			the_number = 0.00000000009
    			print (the_number)

    			#
    			#
    			#
    			the_number = 0.00000000009
    			print (format (the_number, '.50f'))